import os
import time
from ftplib import FTP
# pip install progressbar2
from progressbar import AnimatedMarker, Bar, BouncingBar, Counter, ETA, \
    AdaptiveETA, FileTransferSpeed, FormatLabel, Percentage, \
    ProgressBar, ReverseBar, RotatingMarker, \
    SimpleProgress, Timer, UnknownLength


class NOAA:
    def __init__(self, url, dir_path):
        self.url = url
        self.dir_path = dir_path


    def dir(self):
        ftp = FTP(self.url)
        ftp.login()
        ftp.cwd(self.dir_path)
        ftp.retrlines('LIST')


    def download(self, filename):
        global pbar
        ftp = FTP(self.url)
        ftp.login()
        ftp.cwd(self.dir_path)
        # ftp.retrlines('LIST')
        
        def file_write(data):
            global pbar
            localfile.write(data)
            pbar += len(data)

        localfile = open(filename, 'wb')
        remote_file = filename
        ftp.voidcmd('TYPE I')
        file_size = ftp.size(remote_file)
        widgets = ['Downloading: ', Percentage(), ' ', Bar(marker='#', \
            left='[',right=']'), ' ', ETA(), ' ', FileTransferSpeed()]
        pbar = ProgressBar(widgets=widgets, maxval=file_size)
        pbar.start()
        
        ftp.retrbinary("RETR " + remote_file, file_write)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['noaa_ftp', 'noaa_ftp.noaa']

package_data = \
{'': ['*']}

install_requires = \
['progressbar2==4.0.0']

setup_kwargs = {
    'name': 'noaa-ftp',
    'version': '0.1.10',
    'description': 'A python package to work with NOAA FTP',
    'long_description': '# NOAA-FTP\n\n> I needed to work with data from NOAA, so I write a code in jupyter notebook and solved my problem for viewing and downloading data.\n> Then I decided to convert that code to a python package.\n\nMy Personal Website: [Water Directory](https://waterdirectory.ir/).\n\n\nTo import, use command below:\n\n```bash\nfrom noaa_ftp import NOAA\n```\n\nAvailable functions:\n- dir()\n- download()\n\n## Get list of files and folders\n\n```bash\nnoaa_dir = NOAA("ftp.ncdc.noaa.gov", \'pub/data/ghcn/daily\').dir()\nnoaa_dir\n```\n\n## Download custom file from the directory\n\n```bash\nnoaa = NOAA("ftp.ncdc.noaa.gov", \'pub/data/ghcn/daily\').download(\'ghcnd-stations.txt\')\n```',
    'author': 'javad',
    'author_email': 'javad.rezvanpour@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
